class Pelicula:
	""" Manipula todos los datos y el comportamiento asociado a las peliculas. """
	def __init__(self,imdb_code,name):
    	""" Seteo los atributos inicialmente en 0 y vacio """
    	self.imdb_code= imdb_code if imdb_code is not None and isnumeric(imdb_code) else ""
    	self.name= name if name is not None else ""

    	self.torrents = [] # 
    	self.cast = [] #
    	self.poster = "avatar.jpg"




from setuptools import setup, find_packages

setup(
    name='totonesmovies',
    author='Daniel Flor',
    author_email='danielhernanflor@gmail.com',
    version='0.6dev',
    packages=['totonesmovies'],
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README').read(),
    url='https://github.com/danielhf/totonesmovies',
    dependencies_links=['https://github.com/alberanid/imdbpy'],
    install_requires=['pyquery','requests','pprint']
)